@@ -488,7 +488,11 @@ define ([
                 if (len > 0) {
                     for (i = 0; i < len; i += 1) {
                         entry = dbo.entries[i];
-                        if (lib.privCheck(entry.aclProfileRead)) {
+                        if (entry.name === 'divider') {
+                            r += Array(entry.maxlen).join(entry.text) + '<br>';
+                        } else if (entry.name === 'emptyLine') {
+                            r += '<br>';
+                        } else if (lib.privCheck(entry.aclProfileRead)) {
                             r += lib.rightPadSpaces(entry.text.concat(':'), needed);
                             r += '<span id="' + entry.name + '">';
                             r += valueToDisplay(obj, entry.prop);
